# bluefin-pro-api-client
Bluefin API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import bluefin_pro_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import bluefin_pro_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import bluefin_pro_api_client
from bluefin_pro_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:8080
# See configuration.py for a list of all supported configuration parameters.
configuration = bluefin_pro_api_client.Configuration(
    host = "http://localhost:8080"
)



# Enter a context with an instance of the API client
async with bluefin_pro_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = bluefin_pro_api_client.AccountDataApi(api_client)

    try:
        # Get user's account details.
        api_response = await api_instance.get_account_details()
        print("The response of AccountDataApi->get_account_details:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountDataApi->get_account_details: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8080*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountDataApi* | [**get_account_details**](docs/AccountDataApi.md#get_account_details) | **GET** /api/v1/account | Get user&#39;s account details.
*AccountDataApi* | [**get_account_positions**](docs/AccountDataApi.md#get_account_positions) | **GET** /api/v1/account/positions | Get user&#39;s open positions.
*AccountDataApi* | [**get_account_preferences**](docs/AccountDataApi.md#get_account_preferences) | **GET** /api/v1/account/preferences | Get user&#39;s account preferences.
*AccountDataApi* | [**get_account_trades**](docs/AccountDataApi.md#get_account_trades) | **GET** /api/v1/account/trades | Get user&#39;s trade history.
*AccountDataApi* | [**get_account_transaction_history**](docs/AccountDataApi.md#get_account_transaction_history) | **GET** /api/v1/account/transactions | Get user&#39;s transaction history (any change in balance).
*AuthApi* | [**auth_jwks_get**](docs/AuthApi.md#auth_jwks_get) | **GET** /auth/jwks | 
*AuthApi* | [**auth_token_post**](docs/AuthApi.md#auth_token_post) | **POST** /auth/token | 
*AuthApi* | [**auth_token_refresh_put**](docs/AuthApi.md#auth_token_refresh_put) | **PUT** /auth/token/refresh | 
*ExchangeApi* | [**get_candlestick_data**](docs/ExchangeApi.md#get_candlestick_data) | **GET** /v1/exchange/candlesticks | Kline/candlestick data.
*ExchangeApi* | [**get_exchange_info**](docs/ExchangeApi.md#get_exchange_info) | **GET** /v1/exchange/info | Get exchange information
*ExchangeApi* | [**get_funding_rate_history**](docs/ExchangeApi.md#get_funding_rate_history) | **GET** /v1/exchange/fundingRateHistory | Get funding rate history
*ExchangeApi* | [**get_market_ticker**](docs/ExchangeApi.md#get_market_ticker) | **GET** /v1/exchange/ticker | Aggregated market ticker information
*ExchangeApi* | [**get_orderbook_depth**](docs/ExchangeApi.md#get_orderbook_depth) | **GET** /v1/exchange/depth | Orderbook depth
*ExchangeApi* | [**get_recent_trades**](docs/ExchangeApi.md#get_recent_trades) | **GET** /v1/exchange/trades | Recent trades list
*StreamsApi* | [**web_socket_account_data**](docs/StreamsApi.md#web_socket_account_data) | **GET** /account | WebSocket Account Data streams
*StreamsApi* | [**web_socket_market_data**](docs/StreamsApi.md#web_socket_market_data) | **GET** /market | WebSocket Market Data streams
*TradeApi* | [**cancel_orders**](docs/TradeApi.md#cancel_orders) | **PUT** /api/v1/trade/orders/cancel | Cancel orders for a market using order hashes
*TradeApi* | [**get_open_orders**](docs/TradeApi.md#get_open_orders) | **GET** /api/v1/trade/openOrders | Get Open Orders
*TradeApi* | [**post_create_order**](docs/TradeApi.md#post_create_order) | **POST** /api/v1/trade/orders | Create a new order
*TradeApi* | [**post_withdraw**](docs/TradeApi.md#post_withdraw) | **POST** /api/v1/trade/withdraw | Initiate a withdraw
*TradeApi* | [**put_leverage_update**](docs/TradeApi.md#put_leverage_update) | **PUT** /api/v1/trade/leverage | Updates leverage for positions


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountDataStream](docs/AccountDataStream.md)
 - [AccountEventReason](docs/AccountEventReason.md)
 - [AccountEventType](docs/AccountEventType.md)
 - [AccountMarketPreference](docs/AccountMarketPreference.md)
 - [AccountOrderUpdate](docs/AccountOrderUpdate.md)
 - [AccountPositionLeverageUpdateRequest](docs/AccountPositionLeverageUpdateRequest.md)
 - [AccountPositionLeverageUpdateRequestSignedFields](docs/AccountPositionLeverageUpdateRequestSignedFields.md)
 - [AccountPositionUpdate](docs/AccountPositionUpdate.md)
 - [AccountPreference](docs/AccountPreference.md)
 - [AccountStreamMessage](docs/AccountStreamMessage.md)
 - [AccountStreamMessagePayload](docs/AccountStreamMessagePayload.md)
 - [AccountSubscriptionMessage](docs/AccountSubscriptionMessage.md)
 - [AccountTradeUpdate](docs/AccountTradeUpdate.md)
 - [AccountTransactionUpdate](docs/AccountTransactionUpdate.md)
 - [AccountUpdate](docs/AccountUpdate.md)
 - [ActiveOrderUpdate](docs/ActiveOrderUpdate.md)
 - [Asset](docs/Asset.md)
 - [Asset1](docs/Asset1.md)
 - [Asset2](docs/Asset2.md)
 - [CancelOrdersRequest](docs/CancelOrdersRequest.md)
 - [CandlePriceType](docs/CandlePriceType.md)
 - [CandlestickInterval](docs/CandlestickInterval.md)
 - [CandlestickPriceType](docs/CandlestickPriceType.md)
 - [CandlestickStream](docs/CandlestickStream.md)
 - [CandlestickUpdate](docs/CandlestickUpdate.md)
 - [CreateOrderRequest](docs/CreateOrderRequest.md)
 - [CreateOrderRequestSignOrderFields](docs/CreateOrderRequestSignOrderFields.md)
 - [DiffDepthStream](docs/DiffDepthStream.md)
 - [Error](docs/Error.md)
 - [Error1](docs/Error1.md)
 - [Error2](docs/Error2.md)
 - [ExchangeInfoResponse](docs/ExchangeInfoResponse.md)
 - [FeeTier](docs/FeeTier.md)
 - [FundingRateEntry](docs/FundingRateEntry.md)
 - [KlineInterval](docs/KlineInterval.md)
 - [LoginRequest](docs/LoginRequest.md)
 - [LoginResponse](docs/LoginResponse.md)
 - [MarginTypeEnum](docs/MarginTypeEnum.md)
 - [MarkPriceStream](docs/MarkPriceStream.md)
 - [Market](docs/Market.md)
 - [MarketDataStream](docs/MarketDataStream.md)
 - [MarketEventType](docs/MarketEventType.md)
 - [MarketPriceStream](docs/MarketPriceStream.md)
 - [MarketStatus](docs/MarketStatus.md)
 - [MarketStreamMessage](docs/MarketStreamMessage.md)
 - [MarketStreamMessagePayload](docs/MarketStreamMessagePayload.md)
 - [MarketSubscriptionMessage](docs/MarketSubscriptionMessage.md)
 - [OpenOrderResponse](docs/OpenOrderResponse.md)
 - [OraclePriceStream](docs/OraclePriceStream.md)
 - [OrderCancelReason](docs/OrderCancelReason.md)
 - [OrderCancellationFailureReason](docs/OrderCancellationFailureReason.md)
 - [OrderCancellationUpdate](docs/OrderCancellationUpdate.md)
 - [OrderSide](docs/OrderSide.md)
 - [OrderStatus](docs/OrderStatus.md)
 - [OrderStatus1](docs/OrderStatus1.md)
 - [OrderTimeInForce](docs/OrderTimeInForce.md)
 - [OrderTimeInForce1](docs/OrderTimeInForce1.md)
 - [OrderType](docs/OrderType.md)
 - [OrderType1](docs/OrderType1.md)
 - [OrderbookDepthResponse](docs/OrderbookDepthResponse.md)
 - [OrderbookDiffDepthUpdate](docs/OrderbookDiffDepthUpdate.md)
 - [OrderbookPartialDepthUpdate](docs/OrderbookPartialDepthUpdate.md)
 - [PartialDepthStream](docs/PartialDepthStream.md)
 - [Position](docs/Position.md)
 - [PositionSideEnum](docs/PositionSideEnum.md)
 - [PostCreateOrder202Response](docs/PostCreateOrder202Response.md)
 - [PriceUpdate](docs/PriceUpdate.md)
 - [RecentTradeStream](docs/RecentTradeStream.md)
 - [RecentTradeUpdate](docs/RecentTradeUpdate.md)
 - [RecentTradeUpdates](docs/RecentTradeUpdates.md)
 - [RefreshTokenRequest](docs/RefreshTokenRequest.md)
 - [RefreshTokenResponse](docs/RefreshTokenResponse.md)
 - [SelfTradePreventionType](docs/SelfTradePreventionType.md)
 - [SelfTradePreventionType1](docs/SelfTradePreventionType1.md)
 - [Side](docs/Side.md)
 - [SubscriptionResponseMessage](docs/SubscriptionResponseMessage.md)
 - [SubscriptionType](docs/SubscriptionType.md)
 - [TickerAllStream](docs/TickerAllStream.md)
 - [TickerAllUpdate](docs/TickerAllUpdate.md)
 - [TickerResponse](docs/TickerResponse.md)
 - [TickerStream](docs/TickerStream.md)
 - [TickerUpdate](docs/TickerUpdate.md)
 - [Trade](docs/Trade.md)
 - [Trade1](docs/Trade1.md)
 - [TradeSide](docs/TradeSide.md)
 - [TradeSideEnum](docs/TradeSideEnum.md)
 - [TradeType](docs/TradeType.md)
 - [TradeTypeEnum](docs/TradeTypeEnum.md)
 - [TradingFees](docs/TradingFees.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionType](docs/TransactionType.md)
 - [TransactionTypeEnum](docs/TransactionTypeEnum.md)
 - [WithdrawRequest](docs/WithdrawRequest.md)
 - [WithdrawRequestSignWithdrawFields](docs/WithdrawRequestSignWithdrawFields.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




